# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/object_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from aruna.api.storage.models.v1 import query_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2aruna/api/storage/services/v1/object_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\'aruna/api/storage/models/v1/query.proto\x1a\x1cgoogle/api/annotations.proto\"\x17\n\x03URL\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\"\x90\x03\n\x0bStageObject\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x1f\n\x0b\x63ontent_len\x18\x04 \x01(\x03R\ncontentLen\x12;\n\x06source\x18\x05 \x01(\x0b\x32#.aruna.api.storage.models.v1.SourceR\x06source\x12\x44\n\tdataclass\x18\x06 \x01(\x0e\x32&.aruna.api.storage.models.v1.DataClassR\tdataclass\x12=\n\x06labels\x18\x07 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x08 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\"\x82\x02\n\x1aInitializeNewObjectRequest\x12\x42\n\x06object\x18\x01 \x01(\x0b\x32*.aruna.api.storage.services.v1.StageObjectR\x06object\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x32\n\x15preferred_endpoint_id\x18\x04 \x01(\tR\x13preferredEndpointId\x12\x1c\n\tmultipart\x18\x05 \x01(\x08R\tmultipart\x12)\n\x10is_specification\x18\x06 \x01(\x08R\x0fisSpecification\"|\n\x1bInitializeNewObjectResponse\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\"\xb3\x01\n\x13GetUploadURLRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x1c\n\tmultipart\x18\x04 \x01(\x08R\tmultipart\x12\x1f\n\x0bpart_number\x18\x05 \x01(\x05R\npartNumber\"L\n\x14GetUploadURLResponse\x12\x34\n\x03url\x18\x01 \x01(\x0b\x32\".aruna.api.storage.services.v1.URLR\x03url\"8\n\x0e\x43ompletedParts\x12\x12\n\x04\x65tag\x18\x01 \x01(\tR\x04\x65tag\x12\x12\n\x04part\x18\x02 \x01(\x03R\x04part\"Y\n\x15GetDownloadURLRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\"N\n\x16GetDownloadURLResponse\x12\x34\n\x03url\x18\x01 \x01(\x0b\x32\".aruna.api.storage.services.v1.URLR\x03url\"]\n\x1cGetDownloadLinksBatchRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x18\n\x07objects\x18\x02 \x03(\tR\x07objects\"W\n\x1dGetDownloadLinksBatchResponse\x12\x36\n\x04urls\x18\x01 \x03(\x0b\x32\".aruna.api.storage.services.v1.URLR\x04urls\"a\n CreateDownloadLinksStreamRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x18\n\x07objects\x18\x02 \x03(\tR\x07objects\"Y\n!CreateDownloadLinksStreamResponse\x12\x34\n\x03url\x18\x01 \x01(\x0b\x32\".aruna.api.storage.services.v1.URLR\x03url\"\xc8\x02\n\x1a\x46inishObjectStagingRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x35\n\x04hash\x18\x04 \x01(\x0b\x32!.aruna.api.storage.models.v1.HashR\x04hash\x12\x1b\n\tno_upload\x18\x05 \x01(\x08R\x08noUpload\x12V\n\x0f\x63ompleted_parts\x18\x06 \x03(\x0b\x32-.aruna.api.storage.services.v1.CompletedPartsR\x0e\x63ompletedParts\x12\x1f\n\x0b\x61uto_update\x18\x07 \x01(\x08R\nautoUpdate\"Z\n\x1b\x46inishObjectStagingResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\xcb\x02\n\x13UpdateObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x42\n\x06object\x18\x03 \x01(\x0b\x32*.aruna.api.storage.services.v1.StageObjectR\x06object\x12\x1a\n\x08reupload\x18\x04 \x01(\x08R\x08reupload\x12\x32\n\x15preferred_endpoint_id\x18\x05 \x01(\tR\x13preferredEndpointId\x12\x1d\n\nmulti_part\x18\x06 \x01(\x08R\tmultiPart\x12)\n\x10is_specification\x18\x07 \x01(\x08R\x0fisSpecification\x12\x14\n\x05\x66orce\x18\x08 \x01(\x08R\x05\x66orce\"w\n\x14UpdateObjectResponse\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1d\n\nstaging_id\x18\x02 \x01(\tR\tstagingId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\"\xd1\x01\n\x1c\x43reateObjectReferenceRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x30\n\x14target_collection_id\x18\x03 \x01(\tR\x12targetCollectionId\x12\x1c\n\twriteable\x18\x04 \x01(\x08R\twriteable\x12\x1f\n\x0b\x61uto_update\x18\x05 \x01(\x08R\nautoUpdate\"\x1f\n\x1d\x43reateObjectReferenceResponse\"\x88\x01\n\x12\x43loneObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x30\n\x14target_collection_id\x18\x03 \x01(\tR\x12targetCollectionId\"R\n\x13\x43loneObjectResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\x94\x01\n\x13\x44\x65leteObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12%\n\x0ewith_revisions\x18\x03 \x01(\x08R\rwithRevisions\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x16\n\x14\x44\x65leteObjectResponse\"\x97\x01\n\x14\x44\x65leteObjectsRequest\x12\x1d\n\nobject_ids\x18\x01 \x03(\tR\tobjectIds\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12%\n\x0ewith_revisions\x18\x03 \x01(\x08R\rwithRevisions\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x17\n\x15\x44\x65leteObjectsResponse\"^\n\rObjectWithURL\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\"s\n\x14GetObjectByIDRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12\x19\n\x08with_url\x18\x04 \x01(\x08R\x07withUrl\"]\n\x15GetObjectByIDResponse\x12\x44\n\x06object\x18\x01 \x01(\x0b\x32,.aruna.api.storage.services.v1.ObjectWithURLR\x06object\"\xf5\x01\n\x11GetObjectsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12K\n\x0cpage_request\x18\x02 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\x12S\n\x0flabel_id_filter\x18\x03 \x01(\x0b\x32+.aruna.api.storage.models.v1.LabelOrIDQueryR\rlabelIdFilter\x12\x19\n\x08with_url\x18\x04 \x01(\x08R\x07withUrl\"\\\n\x12GetObjectsResponse\x12\x46\n\x07objects\x18\x01 \x03(\x0b\x32,.aruna.api.storage.services.v1.ObjectWithURLR\x07objects\"\xc5\x01\n\x19GetObjectRevisionsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12K\n\x0cpage_request\x18\x03 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\x12\x19\n\x08with_url\x18\x04 \x01(\x08R\x07withUrl\"d\n\x1aGetObjectRevisionsResponse\x12\x46\n\x07objects\x18\x01 \x03(\x0b\x32,.aruna.api.storage.services.v1.ObjectWithURLR\x07objects\"b\n\x1eGetLatestObjectRevisionRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\"^\n\x1fGetLatestObjectRevisionResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"]\n\x19GetObjectEndpointsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\"a\n\x1aGetObjectEndpointsResponse\x12\x43\n\tendpoints\x18\x01 \x03(\x0b\x32%.aruna.api.storage.models.v1.EndpointR\tendpoints\"\xa7\x01\n\x18\x41\x64\x64LabelsToObjectRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12I\n\rlabels_to_add\x18\x03 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x0blabelsToAdd\"X\n\x19\x41\x64\x64LabelsToObjectResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\x98\x01\n\x17SetHooksOfObjectRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12;\n\x05hooks\x18\x03 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\"W\n\x18SetHooksOfObjectResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\x7f\n\x14GetReferencesRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12%\n\x0ewith_revisions\x18\x03 \x01(\x08R\rwithRevisions\"\x9f\x01\n\x0fObjectReference\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\'\n\x0frevision_number\x18\x03 \x01(\x03R\x0erevisionNumber\x12!\n\x0cis_writeable\x18\x04 \x01(\x08R\x0bisWriteable\"g\n\x15GetReferencesResponse\x12N\n\nreferences\x18\x01 \x03(\x0b\x32..aruna.api.storage.services.v1.ObjectReferenceR\nreferences2\x88\x1e\n\rObjectService\x12\xbe\x01\n\x13InitializeNewObject\x12\x39.aruna.api.storage.services.v1.InitializeNewObjectRequest\x1a:.aruna.api.storage.services.v1.InitializeNewObjectResponse\"0\x82\xd3\xe4\x93\x02*:\x01*\"%/v1/collection/{collection_id}/object\x12\xcd\x01\n\x0cGetUploadURL\x12\x32.aruna.api.storage.services.v1.GetUploadURLRequest\x1a\x33.aruna.api.storage.services.v1.GetUploadURLResponse\"T\x82\xd3\xe4\x93\x02N\x12L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/upload\x12\xc1\x01\n\x0eGetDownloadURL\x12\x34.aruna.api.storage.services.v1.GetDownloadURLRequest\x1a\x35.aruna.api.storage.services.v1.GetDownloadURLResponse\"B\x82\xd3\xe4\x93\x02<\x12:/v1/collection/{collection_id}/object/{object_id}/download\x12\xc8\x01\n\x15GetDownloadLinksBatch\x12;.aruna.api.storage.services.v1.GetDownloadLinksBatchRequest\x1a<.aruna.api.storage.services.v1.GetDownloadLinksBatchResponse\"4\x82\xd3\xe4\x93\x02.\x12,/v1/collection/{collection_id}/objects/batch\x12\xda\x01\n\x19\x43reateDownloadLinksStream\x12?.aruna.api.storage.services.v1.CreateDownloadLinksStreamRequest\x1a@.aruna.api.storage.services.v1.CreateDownloadLinksStreamResponse\"8\x82\xd3\xe4\x93\x02\x32:\x01*\"-/v1/collection/{collection_id}/objects/stream0\x01\x12\xe5\x01\n\x13\x46inishObjectStaging\x12\x39.aruna.api.storage.services.v1.FinishObjectStagingRequest\x1a:.aruna.api.storage.services.v1.FinishObjectStagingResponse\"W\x82\xd3\xe4\x93\x02Q:\x01*2L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/finish\x12\xbc\x01\n\x0cUpdateObject\x12\x32.aruna.api.storage.services.v1.UpdateObjectRequest\x1a\x33.aruna.api.storage.services.v1.UpdateObjectResponse\"C\x82\xd3\xe4\x93\x02=:\x01*\"8/v1/collection/{collection_id}/object/{object_id}/update\x12\xf1\x01\n\x15\x43reateObjectReference\x12;.aruna.api.storage.services.v1.CreateObjectReferenceRequest\x1a<.aruna.api.storage.services.v1.CreateObjectReferenceResponse\"]\x82\xd3\xe4\x93\x02W:\x01*\"R/v1/collection/{collection_id}/object/{object_id}/reference/{target_collection_id}\x12\xb8\x01\n\x0b\x43loneObject\x12\x31.aruna.api.storage.services.v1.CloneObjectRequest\x1a\x32.aruna.api.storage.services.v1.CloneObjectResponse\"B\x82\xd3\xe4\x93\x02<:\x01*\"7/v1/collection/{collection_id}/object/{object_id}/clone\x12\xb5\x01\n\x0c\x44\x65leteObject\x12\x32.aruna.api.storage.services.v1.DeleteObjectRequest\x1a\x33.aruna.api.storage.services.v1.DeleteObjectResponse\"<\x82\xd3\xe4\x93\x02\x36:\x01**1/v1/collection/{collection_id}/object/{object_id}\x12\xad\x01\n\rDeleteObjects\x12\x33.aruna.api.storage.services.v1.DeleteObjectsRequest\x1a\x34.aruna.api.storage.services.v1.DeleteObjectsResponse\"1\x82\xd3\xe4\x93\x02+:\x01**&/v1/collection/{collection_id}/objects\x12\xb5\x01\n\rGetObjectByID\x12\x33.aruna.api.storage.services.v1.GetObjectByIDRequest\x1a\x34.aruna.api.storage.services.v1.GetObjectByIDResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/collection/{collection_id}/object/{object_id}\x12\xa1\x01\n\nGetObjects\x12\x30.aruna.api.storage.services.v1.GetObjectsRequest\x1a\x31.aruna.api.storage.services.v1.GetObjectsResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/collection/{collection_id}/objects\x12\xce\x01\n\x12GetObjectRevisions\x12\x38.aruna.api.storage.services.v1.GetObjectRevisionsRequest\x1a\x39.aruna.api.storage.services.v1.GetObjectRevisionsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/v1/collection/{collection_id}/object/{object_id}/revisions\x12\xda\x01\n\x17GetLatestObjectRevision\x12=.aruna.api.storage.services.v1.GetLatestObjectRevisionRequest\x1a>.aruna.api.storage.services.v1.GetLatestObjectRevisionResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/v1/collection/{collection_id}/object/{object_id}/latest\x12\xce\x01\n\x12GetObjectEndpoints\x12\x38.aruna.api.storage.services.v1.GetObjectEndpointsRequest\x1a\x39.aruna.api.storage.services.v1.GetObjectEndpointsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/v1/collection/{collection_id}/object/{object_id}/endpoints\x12\xcf\x01\n\x11\x41\x64\x64LabelsToObject\x12\x37.aruna.api.storage.services.v1.AddLabelsToObjectRequest\x1a\x38.aruna.api.storage.services.v1.AddLabelsToObjectResponse\"G\x82\xd3\xe4\x93\x02\x41:\x01*2</v1/collection/{collection_id}/object/{object_id}/add_labels\x12\xcb\x01\n\x10SetHooksOfObject\x12\x36.aruna.api.storage.services.v1.SetHooksOfObjectRequest\x1a\x37.aruna.api.storage.services.v1.SetHooksOfObjectResponse\"F\x82\xd3\xe4\x93\x02@:\x01*2;/v1/collection/{collection_id}/object/{object_id}/set_hooks\x12\xc0\x01\n\rGetReferences\x12\x33.aruna.api.storage.services.v1.GetReferencesRequest\x1a\x34.aruna.api.storage.services.v1.GetReferencesResponse\"D\x82\xd3\xe4\x93\x02>\x12</v1/collection/{collection_id}/object/{object_id}/referencesB\x8f\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\rObjectServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.object_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\rObjectServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _OBJECTSERVICE.methods_by_name['InitializeNewObject']._options = None
  _OBJECTSERVICE.methods_by_name['InitializeNewObject']._serialized_options = b'\202\323\344\223\002*:\001*\"%/v1/collection/{collection_id}/object'
  _OBJECTSERVICE.methods_by_name['GetUploadURL']._options = None
  _OBJECTSERVICE.methods_by_name['GetUploadURL']._serialized_options = b'\202\323\344\223\002N\022L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/upload'
  _OBJECTSERVICE.methods_by_name['GetDownloadURL']._options = None
  _OBJECTSERVICE.methods_by_name['GetDownloadURL']._serialized_options = b'\202\323\344\223\002<\022:/v1/collection/{collection_id}/object/{object_id}/download'
  _OBJECTSERVICE.methods_by_name['GetDownloadLinksBatch']._options = None
  _OBJECTSERVICE.methods_by_name['GetDownloadLinksBatch']._serialized_options = b'\202\323\344\223\002.\022,/v1/collection/{collection_id}/objects/batch'
  _OBJECTSERVICE.methods_by_name['CreateDownloadLinksStream']._options = None
  _OBJECTSERVICE.methods_by_name['CreateDownloadLinksStream']._serialized_options = b'\202\323\344\223\0022:\001*\"-/v1/collection/{collection_id}/objects/stream'
  _OBJECTSERVICE.methods_by_name['FinishObjectStaging']._options = None
  _OBJECTSERVICE.methods_by_name['FinishObjectStaging']._serialized_options = b'\202\323\344\223\002Q:\001*2L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/finish'
  _OBJECTSERVICE.methods_by_name['UpdateObject']._options = None
  _OBJECTSERVICE.methods_by_name['UpdateObject']._serialized_options = b'\202\323\344\223\002=:\001*\"8/v1/collection/{collection_id}/object/{object_id}/update'
  _OBJECTSERVICE.methods_by_name['CreateObjectReference']._options = None
  _OBJECTSERVICE.methods_by_name['CreateObjectReference']._serialized_options = b'\202\323\344\223\002W:\001*\"R/v1/collection/{collection_id}/object/{object_id}/reference/{target_collection_id}'
  _OBJECTSERVICE.methods_by_name['CloneObject']._options = None
  _OBJECTSERVICE.methods_by_name['CloneObject']._serialized_options = b'\202\323\344\223\002<:\001*\"7/v1/collection/{collection_id}/object/{object_id}/clone'
  _OBJECTSERVICE.methods_by_name['DeleteObject']._options = None
  _OBJECTSERVICE.methods_by_name['DeleteObject']._serialized_options = b'\202\323\344\223\0026:\001**1/v1/collection/{collection_id}/object/{object_id}'
  _OBJECTSERVICE.methods_by_name['DeleteObjects']._options = None
  _OBJECTSERVICE.methods_by_name['DeleteObjects']._serialized_options = b'\202\323\344\223\002+:\001**&/v1/collection/{collection_id}/objects'
  _OBJECTSERVICE.methods_by_name['GetObjectByID']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectByID']._serialized_options = b'\202\323\344\223\0023\0221/v1/collection/{collection_id}/object/{object_id}'
  _OBJECTSERVICE.methods_by_name['GetObjects']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjects']._serialized_options = b'\202\323\344\223\002(\022&/v1/collection/{collection_id}/objects'
  _OBJECTSERVICE.methods_by_name['GetObjectRevisions']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectRevisions']._serialized_options = b'\202\323\344\223\002=\022;/v1/collection/{collection_id}/object/{object_id}/revisions'
  _OBJECTSERVICE.methods_by_name['GetLatestObjectRevision']._options = None
  _OBJECTSERVICE.methods_by_name['GetLatestObjectRevision']._serialized_options = b'\202\323\344\223\002:\0228/v1/collection/{collection_id}/object/{object_id}/latest'
  _OBJECTSERVICE.methods_by_name['GetObjectEndpoints']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectEndpoints']._serialized_options = b'\202\323\344\223\002=\022;/v1/collection/{collection_id}/object/{object_id}/endpoints'
  _OBJECTSERVICE.methods_by_name['AddLabelsToObject']._options = None
  _OBJECTSERVICE.methods_by_name['AddLabelsToObject']._serialized_options = b'\202\323\344\223\002A:\001*2</v1/collection/{collection_id}/object/{object_id}/add_labels'
  _OBJECTSERVICE.methods_by_name['SetHooksOfObject']._options = None
  _OBJECTSERVICE.methods_by_name['SetHooksOfObject']._serialized_options = b'\202\323\344\223\002@:\001*2;/v1/collection/{collection_id}/object/{object_id}/set_hooks'
  _OBJECTSERVICE.methods_by_name['GetReferences']._options = None
  _OBJECTSERVICE.methods_by_name['GetReferences']._serialized_options = b'\202\323\344\223\002>\022</v1/collection/{collection_id}/object/{object_id}/references'
  _URL._serialized_start=198
  _URL._serialized_end=221
  _STAGEOBJECT._serialized_start=224
  _STAGEOBJECT._serialized_end=624
  _INITIALIZENEWOBJECTREQUEST._serialized_start=627
  _INITIALIZENEWOBJECTREQUEST._serialized_end=885
  _INITIALIZENEWOBJECTRESPONSE._serialized_start=887
  _INITIALIZENEWOBJECTRESPONSE._serialized_end=1011
  _GETUPLOADURLREQUEST._serialized_start=1014
  _GETUPLOADURLREQUEST._serialized_end=1193
  _GETUPLOADURLRESPONSE._serialized_start=1195
  _GETUPLOADURLRESPONSE._serialized_end=1271
  _COMPLETEDPARTS._serialized_start=1273
  _COMPLETEDPARTS._serialized_end=1329
  _GETDOWNLOADURLREQUEST._serialized_start=1331
  _GETDOWNLOADURLREQUEST._serialized_end=1420
  _GETDOWNLOADURLRESPONSE._serialized_start=1422
  _GETDOWNLOADURLRESPONSE._serialized_end=1500
  _GETDOWNLOADLINKSBATCHREQUEST._serialized_start=1502
  _GETDOWNLOADLINKSBATCHREQUEST._serialized_end=1595
  _GETDOWNLOADLINKSBATCHRESPONSE._serialized_start=1597
  _GETDOWNLOADLINKSBATCHRESPONSE._serialized_end=1684
  _CREATEDOWNLOADLINKSSTREAMREQUEST._serialized_start=1686
  _CREATEDOWNLOADLINKSSTREAMREQUEST._serialized_end=1783
  _CREATEDOWNLOADLINKSSTREAMRESPONSE._serialized_start=1785
  _CREATEDOWNLOADLINKSSTREAMRESPONSE._serialized_end=1874
  _FINISHOBJECTSTAGINGREQUEST._serialized_start=1877
  _FINISHOBJECTSTAGINGREQUEST._serialized_end=2205
  _FINISHOBJECTSTAGINGRESPONSE._serialized_start=2207
  _FINISHOBJECTSTAGINGRESPONSE._serialized_end=2297
  _UPDATEOBJECTREQUEST._serialized_start=2300
  _UPDATEOBJECTREQUEST._serialized_end=2631
  _UPDATEOBJECTRESPONSE._serialized_start=2633
  _UPDATEOBJECTRESPONSE._serialized_end=2752
  _CREATEOBJECTREFERENCEREQUEST._serialized_start=2755
  _CREATEOBJECTREFERENCEREQUEST._serialized_end=2964
  _CREATEOBJECTREFERENCERESPONSE._serialized_start=2966
  _CREATEOBJECTREFERENCERESPONSE._serialized_end=2997
  _CLONEOBJECTREQUEST._serialized_start=3000
  _CLONEOBJECTREQUEST._serialized_end=3136
  _CLONEOBJECTRESPONSE._serialized_start=3138
  _CLONEOBJECTRESPONSE._serialized_end=3220
  _DELETEOBJECTREQUEST._serialized_start=3223
  _DELETEOBJECTREQUEST._serialized_end=3371
  _DELETEOBJECTRESPONSE._serialized_start=3373
  _DELETEOBJECTRESPONSE._serialized_end=3395
  _DELETEOBJECTSREQUEST._serialized_start=3398
  _DELETEOBJECTSREQUEST._serialized_end=3549
  _DELETEOBJECTSRESPONSE._serialized_start=3551
  _DELETEOBJECTSRESPONSE._serialized_end=3574
  _OBJECTWITHURL._serialized_start=3576
  _OBJECTWITHURL._serialized_end=3670
  _GETOBJECTBYIDREQUEST._serialized_start=3672
  _GETOBJECTBYIDREQUEST._serialized_end=3787
  _GETOBJECTBYIDRESPONSE._serialized_start=3789
  _GETOBJECTBYIDRESPONSE._serialized_end=3882
  _GETOBJECTSREQUEST._serialized_start=3885
  _GETOBJECTSREQUEST._serialized_end=4130
  _GETOBJECTSRESPONSE._serialized_start=4132
  _GETOBJECTSRESPONSE._serialized_end=4224
  _GETOBJECTREVISIONSREQUEST._serialized_start=4227
  _GETOBJECTREVISIONSREQUEST._serialized_end=4424
  _GETOBJECTREVISIONSRESPONSE._serialized_start=4426
  _GETOBJECTREVISIONSRESPONSE._serialized_end=4526
  _GETLATESTOBJECTREVISIONREQUEST._serialized_start=4528
  _GETLATESTOBJECTREVISIONREQUEST._serialized_end=4626
  _GETLATESTOBJECTREVISIONRESPONSE._serialized_start=4628
  _GETLATESTOBJECTREVISIONRESPONSE._serialized_end=4722
  _GETOBJECTENDPOINTSREQUEST._serialized_start=4724
  _GETOBJECTENDPOINTSREQUEST._serialized_end=4817
  _GETOBJECTENDPOINTSRESPONSE._serialized_start=4819
  _GETOBJECTENDPOINTSRESPONSE._serialized_end=4916
  _ADDLABELSTOOBJECTREQUEST._serialized_start=4919
  _ADDLABELSTOOBJECTREQUEST._serialized_end=5086
  _ADDLABELSTOOBJECTRESPONSE._serialized_start=5088
  _ADDLABELSTOOBJECTRESPONSE._serialized_end=5176
  _SETHOOKSOFOBJECTREQUEST._serialized_start=5179
  _SETHOOKSOFOBJECTREQUEST._serialized_end=5331
  _SETHOOKSOFOBJECTRESPONSE._serialized_start=5333
  _SETHOOKSOFOBJECTRESPONSE._serialized_end=5420
  _GETREFERENCESREQUEST._serialized_start=5422
  _GETREFERENCESREQUEST._serialized_end=5549
  _OBJECTREFERENCE._serialized_start=5552
  _OBJECTREFERENCE._serialized_end=5711
  _GETREFERENCESRESPONSE._serialized_start=5713
  _GETREFERENCESRESPONSE._serialized_end=5816
  _OBJECTSERVICE._serialized_start=5819
  _OBJECTSERVICE._serialized_end=9667
# @@protoc_insertion_point(module_scope)
