# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/internal/v1/proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!aruna/api/internal/v1/proxy.proto\x12\x15\x61runa.api.internal.v1\x1a\x1bgoogle/api/visibility.proto\"o\n\x08Location\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32#.aruna.api.internal.v1.LocationTypeR\x04type\x12\x16\n\x06\x62ucket\x18\x02 \x01(\tR\x06\x62ucket\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\"?\n\x08PartETag\x12\x1f\n\x0bpart_number\x18\x01 \x01(\x03R\npartNumber\x12\x12\n\x04\x65tag\x18\x02 \x01(\tR\x04\x65tag\"w\n\x1aInitPresignedUploadRequest\x12;\n\x08location\x18\x01 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\x12\x1c\n\tmultipart\x18\x02 \x01(\x08R\tmultipart\":\n\x1bInitPresignedUploadResponse\x12\x1b\n\tupload_id\x18\x01 \x01(\tR\x08uploadId\"\xba\x01\n\x1f\x43reatePresignedUploadUrlRequest\x12;\n\x08location\x18\x01 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12\x1f\n\x0bpart_number\x18\x03 \x01(\x03R\npartNumber\x12\x1c\n\tmultipart\x18\x04 \x01(\x08R\tmultipart\"4\n CreatePresignedUploadUrlResponse\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\"\xc3\x01\n\x1c\x46inishPresignedUploadRequest\x12\x1b\n\tupload_id\x18\x01 \x01(\tR\x08uploadId\x12>\n\npart_etags\x18\x02 \x03(\x0b\x32\x1f.aruna.api.internal.v1.PartETagR\tpartEtags\x12\x16\n\x06\x62ucket\x18\x03 \x01(\tR\x06\x62ucket\x12\x10\n\x03key\x18\x04 \x01(\tR\x03key\x12\x1c\n\tmultipart\x18\x05 \x01(\x08R\tmultipart\"/\n\x1d\x46inishPresignedUploadResponse\x12\x0e\n\x02ok\x18\x01 \x01(\x08R\x02ok\"/\n\x05Range\x12\x14\n\x05start\x18\x01 \x01(\x03R\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\x03R\x03\x65nd\"\xca\x01\n\x1e\x43reatePresignedDownloadRequest\x12;\n\x08location\x18\x01 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\x12\x1b\n\tis_public\x18\x02 \x01(\x08R\x08isPublic\x12\x32\n\x05range\x18\x03 \x01(\x0b\x32\x1c.aruna.api.internal.v1.RangeR\x05range\x12\x1a\n\x08\x66ilename\x18\x04 \x01(\tR\x08\x66ilename\"3\n\x1f\x43reatePresignedDownloadResponse\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\"6\n\x13\x43reateBucketRequest\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\"\x16\n\x14\x43reateBucketResponse*[\n\x0cLocationType\x12\x1d\n\x19LOCATION_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10LOCATION_TYPE_S3\x10\x01\x12\x16\n\x12LOCATION_TYPE_FILE\x10\x02\x32\xb7\x05\n\x14InternalProxyService\x12~\n\x13InitPresignedUpload\x12\x31.aruna.api.internal.v1.InitPresignedUploadRequest\x1a\x32.aruna.api.internal.v1.InitPresignedUploadResponse\"\x00\x12\x8d\x01\n\x18\x43reatePresignedUploadUrl\x12\x36.aruna.api.internal.v1.CreatePresignedUploadUrlRequest\x1a\x37.aruna.api.internal.v1.CreatePresignedUploadUrlResponse\"\x00\x12\x84\x01\n\x15\x46inishPresignedUpload\x12\x33.aruna.api.internal.v1.FinishPresignedUploadRequest\x1a\x34.aruna.api.internal.v1.FinishPresignedUploadResponse\"\x00\x12\x8a\x01\n\x17\x43reatePresignedDownload\x12\x35.aruna.api.internal.v1.CreatePresignedDownloadRequest\x1a\x36.aruna.api.internal.v1.CreatePresignedDownloadResponse\"\x00\x12i\n\x0c\x43reateBucket\x12*.aruna.api.internal.v1.CreateBucketRequest\x1a+.aruna.api.internal.v1.CreateBucketResponse\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB6Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.internal.v1.proxy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1'
  _INTERNALPROXYSERVICE._options = None
  _INTERNALPROXYSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _LOCATIONTYPE._serialized_start=1325
  _LOCATIONTYPE._serialized_end=1416
  _LOCATION._serialized_start=89
  _LOCATION._serialized_end=200
  _PARTETAG._serialized_start=202
  _PARTETAG._serialized_end=265
  _INITPRESIGNEDUPLOADREQUEST._serialized_start=267
  _INITPRESIGNEDUPLOADREQUEST._serialized_end=386
  _INITPRESIGNEDUPLOADRESPONSE._serialized_start=388
  _INITPRESIGNEDUPLOADRESPONSE._serialized_end=446
  _CREATEPRESIGNEDUPLOADURLREQUEST._serialized_start=449
  _CREATEPRESIGNEDUPLOADURLREQUEST._serialized_end=635
  _CREATEPRESIGNEDUPLOADURLRESPONSE._serialized_start=637
  _CREATEPRESIGNEDUPLOADURLRESPONSE._serialized_end=689
  _FINISHPRESIGNEDUPLOADREQUEST._serialized_start=692
  _FINISHPRESIGNEDUPLOADREQUEST._serialized_end=887
  _FINISHPRESIGNEDUPLOADRESPONSE._serialized_start=889
  _FINISHPRESIGNEDUPLOADRESPONSE._serialized_end=936
  _RANGE._serialized_start=938
  _RANGE._serialized_end=985
  _CREATEPRESIGNEDDOWNLOADREQUEST._serialized_start=988
  _CREATEPRESIGNEDDOWNLOADREQUEST._serialized_end=1190
  _CREATEPRESIGNEDDOWNLOADRESPONSE._serialized_start=1192
  _CREATEPRESIGNEDDOWNLOADRESPONSE._serialized_end=1243
  _CREATEBUCKETREQUEST._serialized_start=1245
  _CREATEBUCKETREQUEST._serialized_end=1299
  _CREATEBUCKETRESPONSE._serialized_start=1301
  _CREATEBUCKETRESPONSE._serialized_end=1323
  _INTERNALPROXYSERVICE._serialized_start=1419
  _INTERNALPROXYSERVICE._serialized_end=2114
# @@protoc_insertion_point(module_scope)
